@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Java compile wrapper-script for 'test_solution.sh'.
+# Java compile wrapper-script for 'compile.sh'.
 # See that script for syntax and more info.
 #
 # This script compiles a statically linked binary with gcj. In
@@ -14,8 +14,10 @@ DEST="$2"
 TMPFILE=`mktemp /tmp/domjudge_gcj_output.XXXXXX` || exit 1
 
 # -Wall:	Report all warnings
+# -O2:		Level 2 optimizations (default for speed)
 # -static:	Static link with all libraries
-gcj -Wall -O2 -static --main=Main -o $DEST $SOURCE > $TMPFILE 2>&1
+# -pipe:	Use pipes for communication between stages of compilation
+gcj -Wall -O2 -static -pipe --main=Main -o $DEST $SOURCE > $TMPFILE 2>&1
 exitcode=$?
 grep -vE 'requires at runtime the shared libraries|libgcj\.a' $TMPFILE
 rm -f $TMPFILE
