@@ -1,5 +1,5 @@
 <?php
-// $Id: lib.database.php 3188 2010-06-03 10:07:57Z pwerken $
+// $Id: lib.database.php 3619 2011-08-24 22:11:45Z eldering $
 
 /******************************************************************************
 * lib.database.php version 1.4.1
@@ -153,6 +153,7 @@ class db
 			case 'update':
 			case 'replace':
 			case 'delete':
+			case 'set':
 				$type = 'update';
 				break;
 
@@ -329,6 +330,8 @@ class db
 		$elapsed_ms = round(1000*(($secs2 - $secs) + ($micros2 - $micros)));
 
 		if ( DEBUG & DEBUG_SQL ) {
+			global $DEBUG_NUM_QUERIES;
+			$DEBUG_NUM_QUERIES++;
 			if ( isset($_SERVER['REMOTE_ADDR']) ) {
 				printf("<p>SQL: $this->database: <tt>%s</tt> ({$elapsed_ms}ms)</p>\n",
 				       htmlspecialchars($query));
