@@ -2,7 +2,7 @@
 /**
  * Error handling functions
  *
- * $Id: lib.error.php 3169 2010-05-16 15:52:48Z eldering $
+ * $Id: lib.error.php 3209 2010-06-12 00:13:43Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -48,7 +48,7 @@ if ( defined('SYSLOG') ) {
 function logmsg($msglevel, $string) {
 	global $verbose, $loglevel;
 
-	$stamp = "[" . date('M d H:i:s') . "] " . SCRIPT_ID . 
+	$stamp = "[" . date('M d H:i:s') . "] " . SCRIPT_ID .
 		(function_exists('posix_getpid') ? "[" . posix_getpid() . "]" : "") .
 		": ";
 
@@ -60,12 +60,16 @@ function logmsg($msglevel, $string) {
 			if ( $msglevel == LOG_ERR ) {
 				echo "<fieldset class=\"error\"><legend>ERROR</legend> " .
 					 $msg . "</fieldset>\n";
+			} else
+			if ( $msglevel == LOG_WARNING ) {
+				echo "<fieldset class=\"warning\"><legend>Warning</legend> " .
+					$msg . "</fieldset>\n";
 			} else {
 				echo "<p>" . $msg . "</p>\n";
 			}
 			// Add strings for non-interactive parsing:
-			if ( $msglevel == LOG_ERR     ) echo "\n<!-- @@@ERROR-$msg@@@ -->\n";
-			if ( $msglevel == LOG_WARNING ) echo "\n<!-- @@@WARNING-$msg@@@ -->\n";
+			if ( $msglevel == LOG_ERR ||
+			     $msglevel == LOG_WARNING ) echo "\n<!-- @@@$msg@@@ -->\n";
 		} else {
 			fwrite(STDERR, $stamp . $string . "\n");
 			fflush(STDERR);
@@ -96,3 +100,10 @@ function error($string) {
 function warning($string) {
 	logmsg(LOG_WARNING, "warning: $string");
 }
+
+/**
+ * Handle exceptions by calling error().
+ */
+function exception_handler($e) {
+	error($e->getMessage());
+}
