@@ -2,16 +2,14 @@
 /**
  * Miscellaneous helper functions
  *
- * $Id: lib.misc.php 2720 2009-06-21 16:11:18Z eldering $
+ * $Id: lib.misc.php 3402 2010-10-27 19:47:17Z kink $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
  */
 
-
-/** Constant to define MySQL datetime format in PHP date() function notation. */
-define('MYSQL_DATETIME_FORMAT', 'Y-m-d H:i:s');
-
+/** Constant to define MySQL datetime format in strftime() function notation. */
+define('MYSQL_DATETIME_FORMAT', '%Y-%m-%d %H:%M:%S');
 
 /**
  * helperfunction to read all contents from a file.
@@ -50,7 +48,8 @@ function getCurContest($fulldata = FALSE) {
 
 	global $DB;
 	$now = $DB->q('MAYBETUPLE SELECT * FROM contest
-	               WHERE activatetime <= NOW() ORDER BY activatetime DESC LIMIT 1');
+	               WHERE enabled = 1 AND activatetime <= NOW()
+	               ORDER BY activatetime DESC LIMIT 1');
 
 	if ($now == NULL)
 		return FALSE;
@@ -58,6 +57,23 @@ function getCurContest($fulldata = FALSE) {
 		return ( $fulldata ? $now : $now['cid'] );
 }
 
+/**
+ * Returns whether the problem with probid is visible to teams and the
+ * public. That is, it is in the active contest, which has started and
+ * it is submittable.
+ */
+function problemVisible($probid)
+{
+	global $DB, $cdata;
+
+	if ( empty($probid) ) return FALSE;
+	if ( !$cdata || difftime(now(),$cdata['starttime']) < 0 ) return FALSE;
+
+	return $DB->q('MAYBETUPLE SELECT probid FROM problem
+	               WHERE cid = %i AND allow_submit = 1 AND probid = %s',
+	              $cdata['cid'], $probid) !== NULL;
+}
+
 /**
  * Scoreboard calculation
  *
@@ -73,7 +89,7 @@ function getCurContest($fulldata = FALSE) {
 function calcScoreRow($cid, $team, $prob) {
 	global $DB;
 
-	$result = $DB->q('SELECT result, verified, 
+	$result = $DB->q('SELECT result, verified,
 	                  (UNIX_TIMESTAMP(submittime)-UNIX_TIMESTAMP(c.starttime))/60 AS timediff,
 	                  (c.freezetime IS NOT NULL && submittime >= c.freezetime) AS afterfreeze
 	                  FROM judging j
@@ -87,18 +103,18 @@ function calcScoreRow($cid, $team, $prob) {
 	$balloon = $DB->q('MAYBEVALUE SELECT balloon FROM scoreboard_jury
                        WHERE cid = %i AND teamid = %s AND probid = %s',
 	                  $cid, $team, $prob);
-	
+
 	if ( ! $balloon ) $balloon = 0;
-	
+
 	// reset vars
-	$submitted_j = $penalty_j = $time_j = $correct_j = 0;
-	$submitted_p = $penalty_p = $time_p = $correct_p = 0;
+	$submitted_j = $time_j = $correct_j = 0;
+	$submitted_p = $time_p = $correct_p = 0;
 
 	// for each submission
 	while( $row = $result->next() ) {
 
 		if ( VERIFICATION_REQUIRED && ! $row['verified'] ) continue;
-		
+
 		$submitted_j++;
 		if ( ! $row['afterfreeze'] ) $submitted_p++;
 
@@ -111,43 +127,89 @@ function calcScoreRow($cid, $team, $prob) {
 				$correct_p = 1;
 				$time_p = round((int)@$row['timediff']);
 			}
-			// if correct, we don't add penalty time for any later submissions
+			// stop counting after a first correct submission
 			break;
 		}
-
-		// extra penalty minutes for each submission
-		// (will only be counted if this problem is correctly solved)
-		$penalty_j += PENALTY_TIME;
-		if ( ! $row['afterfreeze'] ) $penalty_p += PENALTY_TIME;
-		
 	}
 
-	// calculate penalty time: only when correct add it to the total
-	if ( $correct_j == 0 ) $penalty_j = 0;
-	if ( $correct_p == 0 ) $penalty_p = 0;
-
 	// insert or update the values in the public/team scores table
 	$DB->q('REPLACE INTO scoreboard_public
-	        (cid, teamid, probid, submissions, totaltime, penalty, is_correct)
-	        VALUES (%i,%s,%s,%i,%i,%i,%i)',
-	       $cid, $team, $prob, $submitted_p, $time_p, $penalty_p, $correct_p);
+	        (cid, teamid, probid, submissions, totaltime, is_correct)
+	        VALUES (%i,%s,%s,%i,%i,%i)',
+	       $cid, $team, $prob, $submitted_p, $time_p, $correct_p);
 
 	// insert or update the values in the jury scores table
 	$DB->q('REPLACE INTO scoreboard_jury
-	        (cid, teamid, probid, submissions, totaltime, penalty, is_correct, balloon)
-	        VALUES (%i,%s,%s,%i,%i,%i,%i,%i)',
-	       $cid, $team, $prob, $submitted_j, $time_j, $penalty_j, $correct_j, $balloon);
+	        (cid, teamid, probid, submissions, totaltime, is_correct, balloon)
+	        VALUES (%i,%s,%s,%i,%i,%i,%i)',
+	       $cid, $team, $prob, $submitted_j, $time_j, $correct_j, $balloon);
 
 	return;
 }
 
+/**
+ * Determines final result for a judging given an ordered array of
+ * testcase results. Testcase results can have value NULL if not run
+ * yet. A return value of NULL means that a final result cannot be
+ * determined yet; this may only occur when not all testcases have
+ * been run yet.
+ */
+function getFinalResult($runresults)
+{
+	global $RESULTS_PRIO, $RESULTS_REMAP;
+
+	// Whether we have NULL results
+	$havenull = FALSE;
+
+	// This stores the current result and priority to be returned:
+	$bestres  = NULL;
+	$bestprio = -1;
+
+	// Find first highest priority result:
+	foreach ( $runresults as $tc => $res ) {
+		if ( $res===NULL ) {
+			$havenull = TRUE;
+		} else {
+			$prio = $RESULTS_PRIO[$res];
+			if ( empty($prio) ) error("Unknown result '$res' found.");
+			if ( $prio>$bestprio ) {
+				$bestres  = $res;
+				$bestprio = $prio;
+			}
+		}
+	}
+
+	// Not all results are in yet, and we don't do lazy evaluation:
+	if ( $havenull && ! LAZY_EVAL_RESULTS ) return NULL;
+
+	if ( LAZY_EVAL_RESULTS ) {
+		// If we have NULL results, check whether the highest priority
+		// result has maximal priority. Use a local copy of the
+		// RESULTS_PRIO array, keeping the original untouched.
+		$tmp = $RESULTS_PRIO;
+		rsort($tmp);
+		$maxprio = reset($tmp);
+
+//		echo "maxprio = $maxprio\n";
+		// No highest priority result found: no final answer yet.
+		if ( $havenull && $bestprio<$maxprio ) return NULL;
+	}
+
+	// We have a (possibly lazy) final answer, check for remapping.
+	if ( array_key_exists($bestres, $RESULTS_REMAP) ) {
+		return $RESULTS_REMAP[$bestres];
+	} else {
+		return $bestres;
+	}
+}
+
 /**
  * Simulate MySQL NOW() function to create insert queries that do not
  * change when replicated later.
  */
 function now()
 {
-	return date(MYSQL_DATETIME_FORMAT);
+	return strftime(MYSQL_DATETIME_FORMAT);
 }
 
 /**
@@ -185,13 +247,13 @@ function mkstemps($template, $suffixlen)
 	$TMP_MAX = 16384;
 
 	umask(0133);
-	
+
 	for($try=0; $try<$TMP_MAX; $try++) {
 		$value = mt_rand();
 
 		$filename = $template;
 		$pos = strlen($filename)-$suffixlen-6;
-		
+
 		for($i=0; $i<6; $i++) {
 			$filename{$pos+$i} = $letters{$value % 62};
 			$value /= 62;
@@ -237,7 +299,7 @@ function expandipaddr($addr)
 		if ( empty($addr) ) return NULL;
 		return '0000:0000:0000:0000:0000:0000:'.$addr;
 	}
-	
+
 	// Check for IPv4 notation in last part of addr and translate
 	$ip4 = substr($addr,strrpos($addr,':')+1);
 	if ( strstr($ip4,'.') ) {
@@ -245,14 +307,14 @@ function expandipaddr($addr)
 		if ( empty($ip4) ) return NULL;
 		$addr = substr($addr,0,strrpos($addr,':')+1).$ip4;
 	}
-	
+
 	// Check for IPv6 compressed form and expand
 	if ( strstr($addr,'::') ) {
 		list($pre, $post) = explode('::',$addr,2);
-		
+
 		// Check for single '::' separator
 		if ( strstr($post,'::') ) return NULL;
-		
+
 		// Check and reject unspecified addresses
 		if ( empty($pre) && empty($post) ) return NULL;
 
@@ -267,7 +329,7 @@ function expandipaddr($addr)
 		} else {
 			$npost = count(explode(':',$post));
 		}
-		
+
 		// Create mid part to replace compressed '::' with
 		$mid = ':';
 		for($i=0; $i<8-($npre+$npost); $i++) $mid .= '0:';
@@ -277,7 +339,7 @@ function expandipaddr($addr)
 
 		$addr = str_replace('::',$mid,$addr);
 	}
-	
+
 	// Expand all single quads to 4-digit length
 	$quads = explode(':',$addr);
 	if ( count($quads)!=8 ) return NULL;
@@ -320,7 +382,7 @@ function compareipaddr($ip1, $ip2)
 	if ( $ip2=='0000:0000:0000:0000:0000:0000:7F00:0001' ) {
 		$ip2 = '0000:0000:0000:0000:0000:0000:0000:0001';
 	}
-*/	
+*/
 	return $ip1==$ip2;
 }
 
@@ -332,7 +394,7 @@ function sig_handler($signal)
 	global $exitsignalled;
 
 	logmsg(LOG_DEBUG, "Signal $signal received");
-	
+
 	switch ( $signal ) {
 	case SIGTERM:
 	case SIGHUP:
@@ -346,7 +408,7 @@ function initsignals()
 	global $exitsignalled;
 
 	$exitsignalled = FALSE;
-	
+
 	if ( ! function_exists('pcntl_signal') ) {
 		logmsg(LOG_INFO, "Signal handling not available");
 		return;
@@ -367,10 +429,9 @@ function initsignals()
  * validates it and puts it into the database. Additionally it
  * moves it to a backup storage.
  */
-function submit_solution($team, $ip, $prob, $langext, $file)
+function submit_solution($team, $prob, $langext, $file)
 {
 	if( empty($team)    ) error("No value for Team.");
-	if( empty($ip)      ) error("No value for IP.");
 	if( empty($prob)    ) error("No value for Problem.");
 	if( empty($langext) ) error("No value for Language.");
 	if( empty($file)    ) error("No value for Filename.");
@@ -379,7 +440,7 @@ function submit_solution($team, $ip, $prob, $langext, $file)
 
 	// If no contest has started yet, refuse submissions.
 	$now = now();
-	
+
 	if( difftime($cdata['starttime'], $now) > 0 ) {
 		error("The contest is closed, no submissions accepted. [c$cid]");
 	}
@@ -389,20 +450,10 @@ function submit_solution($team, $ip, $prob, $langext, $file)
 						  extension = %s AND allow_submit = 1', $langext) ) {
 		error("Language '$langext' not found in database or not submittable.");
 	}
-	if( ! $teamrow = $DB->q('MAYBETUPLE SELECT * FROM team WHERE login = %s',$team) ) {
+	if( ! $login = $DB->q('MAYBEVALUE SELECT login FROM team WHERE login = %s',$team) ) {
 		error("Team '$team' not found in database.");
 	}
-	$team = $teamrow['login'];
-	if( ! compareipaddr($teamrow['ipaddress'],$ip) ) {
-		if ( $teamrow['ipaddress'] == NULL && ! STRICTIPCHECK ) {
-			$hostname = gethostbyaddr($ip);
-			if ( $hostname == $ip ) $hostname = NULL;
-			$DB->q('UPDATE team SET ipaddress = %s, hostname = %s WHERE login = %s',$ip,$hostname,$team);
-			logmsg (LOG_NOTICE, "Registered team '$team' at address '$ip'.");
-		} else {
-			error("Team '$team' not registered at this IP address.");
-		}
-	}
+	$team = $login;
 	if( ! $probid = $DB->q('MAYBEVALUE SELECT probid FROM problem WHERE probid = %s
 							AND cid = %i AND allow_submit = "1"', $prob, $cid) ) {
 		error("Problem '$prob' not found in database or not submittable [c$cid].");
@@ -411,7 +462,7 @@ function submit_solution($team, $ip, $prob, $langext, $file)
 		error("File '$file' not found (or not readable).");
 	}
 	if( filesize($file) > SOURCESIZE*1024 ) {
-		error("Submission file is larger than ".SOURCESIZE." kB."); 
+		error("Submission file is larger than ".SOURCESIZE." kB.");
 	}
 
 	logmsg (LOG_INFO, "input verified");
@@ -468,23 +519,6 @@ function version()
 	exit(0);
 }
 
-/**
- * Links helper.
- */
-function make_link($name, $url, $condition = TRUE, $raw = FALSE)
-{
-	$result = $name;
-
-	if (!$raw)
-		$result = htmlspecialchars($result);
-
-	if ($condition && ($url != NULL)) {
-		$result = '<a href="' . htmlspecialchars($url) . '">' . $result . '</a>';
-	}
-
-	return $result;
-}
-
 /**
  * Word wrap only unquoted text.
  */
@@ -514,7 +548,7 @@ function wrap_unquoted($text, $width = 75, $quote = '>')
 
 /**
  * DOM XML tree helper functions (PHP 5).
- * The XML tree is assumed to be named '$xmldoc'.
+ * The XML tree is assumed to be named '$xmldoc' and the XPath object '$xpath'.
  */
 
 /**
@@ -541,3 +575,30 @@ function XMLaddnode($paren, $name, $value = NULL, $attrs = NULL)
 	$paren->appendChild($node);
 	return $node;
 }
+
+/**
+ * Retrieve node by a path from root, or relative to paren if non-null.
+ * Generates error if no or more than one nodes are found.
+ */
+function XMLgetnode($path, $paren = NULL)
+{
+	global $xpath;
+
+	$nodelist = $xpath->query($path,$paren);
+
+	if ( $nodelist->length!=1 ) error("Not exactly one XML node found");
+
+	return $nodelist->item(0);
+}
+
+/**
+ * Returns attribute value of a node, or null if attribute does not exist.
+ */
+function XMLgetattr($node, $attr)
+{
+	$attrnode = $node->attributes->getNamedItem($attr);
+
+	if ( $attrnode===NULL ) return NULL;
+
+	return $attrnode->nodeValue;
+}
