@@ -2,7 +2,7 @@
 /**
  * Common functions shared between team/public/jury interface
  *
- * $Id: common.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: common.php 3490 2010-12-05 16:06:01Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -224,7 +224,7 @@ function putSubmissions($cdata, $restrictions, $limit = 0)
 					, @$restrictions['langid'], @$restrictions['judgehost']
 					);
 		$vercnt = $DB->q('VALUE SELECT count(s.submitid) ' . $sqlbody
-						.' AND verified = 0'
+						.' AND verified = 0 AND result IS NOT NULL'
 					, $cid, @$restrictions['teamid'], @$restrictions['probid']
 					, @$restrictions['langid'], @$restrictions['judgehost']
 					);
