@@ -3,7 +3,7 @@
  * Tool to coordinate the handing out of balloons to teams that solved
  * a problem. Similar to the balloons-daemon, but web-based.
  *
- * $Id: balloons.php 3312 2010-08-09 19:17:26Z eldering $
+ * $Id: balloons.php 3308 2010-08-09 18:59:05Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -19,10 +19,10 @@ if ( isset($_POST['done']) ) {
 			WHERE probid = %s AND teamid = %s AND cid = %i',
 			$parts[0], $parts[1], $parts[2]);
 	}
-	header('Location: ' . getBaseURI() . 'jury/balloons.php');
+	header('Location: balloons.php');
 }
 
-$refresh = '30;url=' . getBaseURI() . 'jury/balloons.php';
+$refresh = '30;url=balloons.php';
 require(LIBWWWDIR . '/header.php');
 require(LIBWWWDIR . '/forms.php');
 
@@ -79,15 +79,17 @@ if ( !empty($BALLOONS) ) {
 		// display an "F" after the time if this is after the freeze.
 		$balloontime = $conteststart + ($row['totaltime']*60);
 		$frozen = (isset($contestfreeze) && $balloontime >= $contestfreeze ?
-			' <span title="After Scoreboard Freeze">F</span>' : '');
-		
-		echo '<td>' . printtime( date(MYSQL_DATETIME_FORMAT, $balloontime) ) .
+			' <span title="After Scoreboard Freeze" class="frozen">F</span>' : '');
+
+		echo '<td>' . printtime( strftime(MYSQL_DATETIME_FORMAT, $balloontime) ) .
 			$frozen . '</td>';
 
 		// the balloon earned
 		echo '<td class="probid">' .
-			'<span style="color: ' . htmlspecialchars($probs_data[$row['probid']]['color']) .
-			'">' . BALLOON_SYM . '</span> ' . htmlspecialchars($row['probid']) . '</td>';
+			'<img style="background-color: ' .
+		    htmlspecialchars($probs_data[$row['probid']]['color']) .
+			';" alt="problem colour ' . htmlspecialchars($probs_data[$row['probid']]['color']) .
+		    '" src="../images/circle.png" /> ' . htmlspecialchars($row['probid']) . '</td>';
 
 		// team name and room
 		echo '<td class="teamid">' . htmlspecialchars($row['login']) . '</td><td>' .
@@ -97,11 +99,12 @@ if ( !empty($BALLOONS) ) {
 		// list of balloons for this team
 		sort($TOTAL_BALLOONS[$row['login']]);
 		foreach($TOTAL_BALLOONS[$row['login']] as $prob_solved) {
-			echo '<span title="' .
-				htmlspecialchars($prob_solved) .
-				'" style="color: ' .
+			echo '<img title="' . htmlspecialchars($prob_solved) .
+				'" style="background-color: ' .
 				htmlspecialchars($probs_data[$prob_solved]['color']) .
-				'">' . BALLOON_SYM . '</span> ';
+				';" alt="problem colour ' .
+				htmlspecialchars($probs_data[$row['probid']]['color']) .
+				'" src="../images/circle.png" /> ';
 		}
 		echo '</td><td>';
 
@@ -117,7 +120,7 @@ if ( !empty($BALLOONS) ) {
 
 	echo "</table>\n\n" . addEndForm();
 } else {
-	echo "<p><em>No correct submissions yet... keep posted!</em></p>\n\n";
+	echo "<p class=\"nodata\">No correct submissions yet... keep posted!</p>\n\n";
 }
 
 
