@@ -6,7 +6,7 @@
  *  - Does not support checkboxes yet, since these
  *    return no value when not checked.
  *
- * $Id: edit.php 2474 2008-11-08 19:46:45Z kink $
+ * $Id: edit.php 3125 2010-02-23 19:14:54Z kink $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -29,6 +29,8 @@ $skipwhenempty = @$_POST['skipwhenempty'];
 $referrer      = @$_POST['referrer'];
 
 if ( empty($data) ) error ("No data.");
+// ensure referrer only contains a single filename, not complete URLs
+if ( ! preg_match('/^[._a-zA-Z0-9?&=]*$/', $referrer ) ) error ("Invalid characters in referrer.");
 
 require(LIBWWWDIR . '/checkers.jury.php');
 
@@ -84,7 +86,7 @@ if ( !empty($referrer) ) {
 	$returnto = ($t == 'team_category' ? 'team_categories' : $t.'s'). '.php';
 }
 
-header('Location: '.getBaseURI().'jury/'.$returnto);
+header('Location: '.$returnto);
 
 /**
  * Check an array with field->value data to make sure there's no
