@@ -2,7 +2,7 @@
 /**
  * Change the valid status of a given submission.
  *
- * $Id: ignore.php 2194 2008-06-28 13:07:04Z eldering $
+ * $Id: ignore.php 3118 2010-02-22 20:23:55Z kink $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -37,5 +37,5 @@ $sdata = $DB->q('TUPLE SELECT submitid, cid, teamid, probid
 calcScoreRow($sdata['cid'], $sdata['teamid'], $sdata['probid']);
 
 /* redirect back. */
-header('Location: '.getBaseURI().'jury/submission.php?id=' .
+header('Location: submission.php?id=' .
 	urlencode($sdata['submitid']));
