@@ -2,7 +2,7 @@
 /**
  * View a problem
  *
- * $Id: problem.php 3169 2010-05-16 15:52:48Z eldering $
+ * $Id: problem.php 3225 2010-07-05 20:42:38Z werth $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -10,21 +10,25 @@
 
 $pagename = basename($_SERVER['PHP_SELF']);
 
-$id = @$_REQUEST['id'];
-
 require('init.php');
 
+$id = @$_REQUEST['id'];
+$title = 'Problem '.htmlspecialchars(@$id);
+
+if ( ! preg_match('/^\w*$/', $id) ) error("Invalid problem id");
+
 if ( isset($_POST['cmd']) ) {
 	$pcmd = $_POST['cmd'];
 } elseif ( isset($_GET['cmd'] ) ) {
 	$cmd = $_GET['cmd'];
 } else {
-	$refresh = '15;url='.getBaseURI().'jury/'.$pagename.'?id='.urlencode($id);
+	$refresh = '15;url='.$pagename.'?id='.urlencode($id);
 }
 
-$title = 'Problem '.htmlspecialchars(@$id);
-
 if ( !empty($pcmd) ) {
+
+	if ( empty($id) ) error("Missing problem id");
+
 	if ( isset($pcmd['toggle_submit']) ) {
 		$DB->q('UPDATE problem SET allow_submit = %i WHERE probid = %s',
 			   $_POST['val']['toggle_submit'], $id);
@@ -35,27 +39,43 @@ if ( !empty($pcmd) ) {
 			   $_POST['val']['toggle_judge'], $id);
 	}
 }
+if ( isset($_POST['upload']) ) {
+	if ( !empty($_FILES['problem_archive']['name']) ) {
+		checkFileUpload( $_FILES['problem_archive']['error'] );
+		$zip = openZipFile($_FILES['problem_archive']['tmp_name']);
+		$id = importZippedProblem($zip, empty($id) ? NULL : $id);
+		$zip->close();
+		$refresh = '15;url='.$pagename.'?id='.urlencode($id);
+	} else {
+		error("Missing filename for problem upload");
+	}
+}
+
+$jscolor=true;
 
 require(LIBWWWDIR . '/header.php');
 require(LIBWWWDIR . '/forms.php');
 
 if ( IS_ADMIN && !empty($cmd) ):
-	
+
 	echo "<h2>" .  htmlspecialchars(ucfirst($cmd)) . " problem</h2>\n\n";
 
-	echo addForm('edit.php');
+	echo addForm('edit.php', 'post', null, 'multipart/form-data');
 
 	echo "<table>\n";
 
 	if ( $cmd == 'edit' ) {
 		echo "<tr><td>Problem ID:</td><td class=\"probid\">";
-		$row = $DB->q('TUPLE SELECT * FROM problem WHERE probid = %s',
-			$_GET['id']);
+		$row = $DB->q('TUPLE SELECT p.*, COUNT(testcaseid) AS testcases
+		               FROM problem p
+		               LEFT JOIN testcase USING (probid)
+		               WHERE probid = %s GROUP BY probid', $id);
 		echo addHidden('keydata[0][probid]', $row['probid']);
 		echo htmlspecialchars($row['probid']);
 	} else {
 		echo "<tr><td><label for=\"data_0__probid_\">Problem ID:</label></td><td>";
 		echo addInput('data[0][probid]', null, 8, 10);
+		echo " (alphanumerics only)";
 	}
 	echo "</td></tr>\n";
 
@@ -77,12 +97,19 @@ echo addSelect('data[0][cid]', $cmap, @$row['cid'], true);
 <tr><td>Allow judge:</td>
 <td><?php echo addRadioButton('data[0][allow_judge]', (!isset($row['allow_judge']) || $row['allow_judge']), 1)?> <label for="data_0__allow_judge_1">yes</label>
 <?php echo addRadioButton('data[0][allow_judge]', (isset($row['allow_judge']) && !$row['allow_judge']), 0)?> <label for="data_0__allow_judge_0">no</label></td></tr>
-
+<?php
+    if ( !empty($row['probid']) ) {
+		echo '<tr><td>Testcases:</td><td>' .
+			$row['testcases'] . ' <a href="testcase.php?probid=' .
+			urlencode($row['probid']) . "\">details/edit</a></td></tr>\n";
+	}
+?>
 <tr><td><label for="data_0__timelimit_">Timelimit:</label></td>
 <td><?php echo addInput('data[0][timelimit]', @$row['timelimit'], 5, 5)?> sec</td></tr>
 
 <tr><td><label for="data_0__color_">Balloon colour:</label></td>
-<td><?php echo addInput('data[0][color]', @$row['color'], 8, 25)?>
+<td><?php echo addInputField('text','data[0][color]', @$row['color'],
+	' size="8" maxlength="25" class="color {required:false,adjust:false,hash:true,caps:false}"')?>
 <a target="_blank"
 href="http://www.w3schools.com/css/css_colornames.asp"><img
 src="../images/b_help.png" class="smallpicto" alt="?" /></a></td></tr>
@@ -92,6 +119,7 @@ src="../images/b_help.png" class="smallpicto" alt="?" /></a></td></tr>
 
 <tr><td><label for="data_0__special_compare_">Special compare script:</label></td>
 <td><?php echo addInput('data[0][special_compare]', @$row['special_compare'], 30, 25)?></td></tr>
+
 </table>
 
 <?php
@@ -102,18 +130,33 @@ echo addHidden('cmd', $cmd) .
 	addSubmit('Cancel', 'cancel') .
 	addEndForm();
 
+
+if ( class_exists("ZipArchive") ) {
+	echo "<br /><span style=\"font-style:italic;\">or</span><br /><br />\n" .
+	addForm('problem.php', 'post', null, 'multipart/form-data') .
+	addHidden('id', @$row['probid']) .
+	'<label for="problem_archive">Upload problem archive:</label>' .
+	addFileField('problem_archive') .
+	addSubmit('Upload', 'upload') .
+	addEndForm();
+}
+
 require(LIBWWWDIR . '/footer.php');
 exit;
 
 endif;
 
-if ( ! $id ) error("Missing or invalid problem id");
+$data = $DB->q('TUPLE SELECT p.*, c.contestname, count(rank) AS ntestcases
+                FROM problem p
+                NATURAL JOIN contest c
+                LEFT JOIN testcase USING (probid)
+                WHERE probid = %s GROUP BY probid', $id);
+
+if ( ! $data ) error("Missing or invalid problem id");
 
 echo "<h1>Problem ".htmlspecialchars($id)."</h1>\n\n";
 
-$data = $DB->q('TUPLE SELECT * FROM problem NATURAL JOIN contest WHERE probid = %s', $id);
-
-echo addForm($pagename) . "<p>\n" .
+echo addForm($pagename, 'post', null, 'multipart/form-data') . "<p>\n" .
 	addHidden('id', $id) .
 	addHidden('val[toggle_judge]',  !$data['allow_judge']) .
 	addHidden('val[toggle_submit]', !$data['allow_submit']).
@@ -134,31 +177,21 @@ echo addForm($pagename) . "<p>\n" .
 		"return confirm('" . ($data['allow_judge'] ? 'Disallow' : 'Allow') .
 		" judging for this problem?')"); ?>
 </td></tr>
-<tr><td scope="row" valign="top">Testcase:    </td><td><?php
-	$tc = $DB->q("MAYBETUPLE SELECT md5sum_input, md5sum_output FROM testcase WHERE probid = %s",
-		$data['probid']);
-	foreach(array('input','output') as $inout) {
-		echo $inout . ": ";
-		if ( $tc['md5sum_' . $inout] ) {
-			echo htmlspecialchars($tc['md5sum_'.$inout]) . " ";
-			if ( IS_ADMIN ) {
-				echo '<a href="testcase.php?probid='.urlencode($data['probid']).'">details</a> | ';
-			}
-			echo "<a href=\"testcase.php?probid=" . urlencode($data['probid']) . "&amp;fetch=" .
-				$inout . "\">download</a>";
-		} else {
-			echo '<a href="testcase.php?probid='.urlencode($data['probid']).'">add</a>';
-		}
-		echo "<br />\n";
+<tr><td scope="row">Testcases:   </td><td><?php
+    if ( $data['ntestcases']==0 ) {
+		echo '<em>no testcases</em>';
+	} else {
+		echo (int)$data['ntestcases'];
 	}
-
+	echo ' <a href="testcase.php?probid='.urlencode($data['probid']).'">details/edit</a>';
 ?></td></tr>
 <tr><td scope="row">Timelimit:   </td><td><?php echo (int)$data['timelimit']?> sec</td></tr>
 <?php
 if ( !empty($data['color']) ) {
-	echo '<tr><td scope="row">Colour:       </td><td><span style="color: ' .
+	echo '<tr><td scope="row">Colour:</td><td><img style="background-color: ' .
 		htmlspecialchars($data['color']) .
-		';">' . BALLOON_SYM . '</span> ' . htmlspecialchars($data['color']) .
+		';" alt="problem colour ' . htmlspecialchars($data['color']) .
+		'" src="../images/circle.png" /> ' . htmlspecialchars($data['color']) .
 		"</td></tr>\n";
 }
 if ( !empty($data['special_run']) ) {
@@ -170,8 +203,15 @@ if ( !empty($data['special_compare']) ) {
 		htmlspecialchars($data['special_compare']) . "</td></tr>\n";
 }
 
-echo "</table>\n" .
-	addEndForm();
+if ( IS_ADMIN && class_exists("ZipArchive") ) {
+	echo '<tr>' .
+		'<td scope="row">Problem archive:</td>' .
+		'<td>' . addFileField('problem_archive') .
+		addSubmit('Upload', 'upload') . '</td>' .
+		"</tr>\n";
+}
+
+echo "</table>\n" . addEndForm();
 
 echo "<br />\n" . rejudgeForm('problem', $id) . "\n\n";
 
