@@ -2,7 +2,7 @@
 /**
  * Show source code from the database.
  *
- * $Id: show_source.php 3198 2010-06-06 22:57:29Z eldering $
+ * $Id: show_source.php 3577 2011-07-30 20:00:45Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -12,6 +12,8 @@ function parseDiff($difftext){
 	$line = strtok($difftext,"\n"); //first line
 	$return = '';
 	while ( strlen($line) != 0 ) {
+		// Strip any additional DOS/MAC newline characters:
+		$line = trim($line, "\r\n");
 		switch ( substr($line,0,1) ) {
 		case '-':
 			$formdiffline = "<span class='diff-old'>".htmlspecialchars($line)."</span>";
@@ -33,11 +35,12 @@ require('init.php');
 $id = (int)$_GET['id'];
 
 $source = $DB->q('MAYBETUPLE SELECT * FROM submission
+                  LEFT JOIN language USING(langid)
                   WHERE submitid = %i',$id);
 if ( empty($source) ) error ("Submission $id not found");
 
 $sourcefile = getSourceFilename($source['cid'],$id,$source['teamid'],
-	$source['probid'],$source['langid']);
+	$source['probid'],$source['extension']);
 
 // Download was requested
 if ( isset($_GET['fetch']) ) {
@@ -50,6 +53,7 @@ if ( isset($_GET['fetch']) ) {
 }
 
 $oldsource = $DB->q('MAYBETUPLE SELECT * FROM submission
+                     LEFT JOIN language USING(langid)
                      WHERE teamid = %s AND probid = %s AND langid = %s AND
                      submittime < %s ORDER BY submittime DESC LIMIT 1',
                     $source['teamid'],$source['probid'],$source['langid'],
@@ -87,7 +91,7 @@ if ( $oldsource ) {
 
 	$oldsourcefile = getSourceFilename($oldsource['cid'],$oldsource['submitid'],
 	                                   $oldsource['teamid'],$oldsource['probid'],
-	                                   $oldsource['langid']);
+	                                   $oldsource['extension']);
 
 	$oldfile = SUBMITDIR.'/'.$oldsourcefile;
 	$newfile = SUBMITDIR.'/'.$sourcefile;
