@@ -2,7 +2,7 @@
 /**
  * View a row in team_affiliation: an institution, company etc
  *
- * $Id: team_affiliation.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: team_affiliation.php 3595 2011-08-14 10:06:53Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -52,7 +52,7 @@ if ( IS_ADMIN && ($cmd == 'add' || $cmd == 'edit') ) {
 <tr><td><label for="data_0__country_">Country:</label></td>
 <td><?php echo addInput('data[0][country]', @$row['country'], 3, 2)?>
 <a target="_blank"
-href="http://www.iso.org/iso/country_codes/iso_3166_code_lists/english_country_names_and_code_elements.htm"><img
+href="http://www.iso.org/iso/country_codes/iso_3166_code_lists/country_names_and_code_elements.htm"><img
 src="../images/b_help.png" class="smallpicto" alt="?" /></a></td></tr>
 
 <tr><td valign="top"><label for="data_0__comments_">Comments:</label></td>
