@@ -2,7 +2,7 @@
 /**
  * View a row in a team_category
  *
- * $Id: team_category.php 3169 2010-05-16 15:52:48Z eldering $
+ * $Id: team_category.php 3164 2010-04-18 20:24:09Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -19,6 +19,7 @@ if ( IS_ADMIN && ($cmd == 'add' || $cmd == 'edit') ) {
 	require(LIBWWWDIR . '/forms.php');
 
 	$title = "Category: " . htmlspecialchars($cmd);
+	$jscolor = true;
 
 	require(LIBWWWDIR . '/header.php');
 	echo "<h2>" . htmlspecialchars(ucfirst($cmd)) . " category</h2>\n\n";
@@ -45,7 +46,8 @@ if ( IS_ADMIN && ($cmd == 'add' || $cmd == 'edit') ) {
 <td><?php echo addInput('data[0][sortorder]', (empty($row['sortorder'])?0:$row['sortorder']), 2, 1)?></td></tr>
 
 <tr><td><label for="data_0__color_">Colour:</label></td>
-<td><?php echo addInput('data[0][color]', @$row['color'], 15, 25)?>
+<td><?php echo addInputField('text','data[0][color]', @$row['color'],
+	'size="15" maxlength="25" class="color {required:false,adjust:false,hash:true,caps:false}"')?>
 <a target="_blank"
 href="http://www.w3schools.com/css/css_colornames.asp"><img
 src="../images/b_help.png" class="smallpicto" alt="?" /></a></td></tr>
@@ -103,16 +105,16 @@ echo "<h2>Teams in " . htmlspecialchars($data['name']) . "</h2>\n\n";
 
 $teams = $DB->q('SELECT login,name FROM team WHERE categoryid = %i', $id);
 if ( $teams->count() == 0 ) {
-	echo "<p><em>no teams</em></p>\n\n";
+	echo "<p class=\"nodata\">no teams</p>\n\n";
 } else {
-	echo "<table>\n<thead>\n" .
+	echo "<table class=\"list\">\n<thead>\n" .
 		"<tr><th scope=\"col\">login</th><th scope=\"col\">teamname</th></tr>\n" .
 		"</thead>\n<tbody>\n";
 	while ($team = $teams->next()) {
-		echo "<tr><td class=\"teamid\"><a href=\"team.php?id=" .
-			urlencode($team['login']) . "\">" .
-			htmlspecialchars($team['login']) . "</a></td><td>" .
-			htmlspecialchars($team['name']) . "</td></tr>\n";
+		$link = '<a href="team.php?id=' . urlencode($team['login']) . '">';
+		echo "<tr><td class=\"teamid\">" .
+		$link . htmlspecialchars($team['login']) . "</a></td><td>" .
+		$link . htmlspecialchars($team['name']) . "</a></td></tr>\n";
 	}
 	echo "</tbody>\n</table>\n\n";
 }
