@@ -3,16 +3,16 @@
  * Produce a total score. Call with parameter 'static' for
  * output suitable for static HTML pages.
  *
- * $Id: index.php 2408 2008-10-05 12:54:51Z sdrongel $
+ * $Id: index.php 3209 2010-06-12 00:13:43Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
  */
- 
+
 require('init.php');
 $title="Scoreboard";
 // set auto refresh
-$refresh="30;url=" . getBaseURI() . 'public/';
+$refresh="30;url=./";
 $menu = false;
 require(LIBWWWDIR . '/header.php');
 require(LIBWWWDIR . '/scoreboard.php');
