@@ -2,13 +2,12 @@
 /**
  * Include required files.
  *
- * $Id: init.php 2653 2009-04-11 18:29:14Z eldering $
+ * $Id: init.php 3146 2010-02-27 10:55:28Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
  */
 
-// please keep any includes synchronised with checkpasswd.php
 require_once('../configure.php');
 
 define('IS_JURY', false);
@@ -24,13 +23,19 @@ require_once(LIBDIR . '/lib.misc.php');
 require_once(LIBDIR . '/lib.dbconfig.php');
 require_once(LIBDIR . '/use_db.php');
 
+set_exception_handler('exception_handler');
 setup_database_connection('team');
 
 require_once(LIBWWWDIR . '/common.php');
 require_once(LIBWWWDIR . '/print.php');
 require_once(LIBWWWDIR . '/clarification.php');
 require_once(LIBWWWDIR . '/scoreboard.php');
-require_once(LIBWWWDIR . '/validate.team.php');
+require_once(LIBWWWDIR . '/auth.team.php');
+
+// The functions do_login and show_loginpage, if called, do not return.
+if ( @$_POST['cmd']=='login' ) do_login();
+
+if ( !logged_in() ) show_loginpage();
 
 $cdata = getCurContest(TRUE);
 $cid = $cdata['cid'];
