@@ -19,6 +19,10 @@ if ( ENABLE_WEBSUBMIT_SERVER ) {
 	echo "<a target=\"_top\" href=\"websubmit.php\" accesskey=\"u\">submit</a>\n";
 }
 
+if ( have_logout() ) {
+	echo "<a target=\"_top\" href=\"logout.php\" accesskey=\"l\">logout</a>\n";
+}
+
 echo "\n</div>\n\n";
 
 putClock();
