@@ -2,14 +2,14 @@
 /**
  * Scoreboard
  *
- * $Id: scoreboard.php 2537 2008-12-01 19:41:11Z eldering $
+ * $Id: scoreboard.php 3118 2010-02-22 20:23:55Z kink $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
  */
 
 require('init.php');
-$refresh = '30;url=' . getBaseURI() . 'team/scoreboard.php';
+$refresh = '30;url=scoreboard.php';
 $title = 'Scoreboard';
 require(LIBWWWDIR . '/header.php');
 
