@@ -2,7 +2,7 @@
 /**
  * Web submissions form
  *
- * $Id: websubmit.php 3149 2010-02-27 12:32:04Z kink $
+ * $Id: websubmit.php 3490 2010-12-05 16:06:01Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -68,8 +68,8 @@ $probs = $DB->q('KEYVALUETABLE SELECT probid, CONCAT(probid,": ",name) as name F
 if( count($probs) == 0 ) {
 	error('No problems defined for this contest');
 }
-$probs = array_merge(array(''=>'by filename'), $probs);
 
+$probs[''] = 'by filename';
 echo addSelect('probid', $probs, '', true);
 
 ?></td>
@@ -84,7 +84,7 @@ if( count($langs) == 0 ) {
 	error('No languages defined');
 }
 
-$langs = array_merge(array(''=>'by extension'), $langs);
+$langs[''] = 'by extension';
 echo addSelect('langext', $langs, '', true);
 
 ?></td>
